<?php
/**
 * functions.php
 *
 * The theme's functions and definitions.
 */

/**
 * ----------------------------------------------------------------------------------------
 * 1.0 - Define constants.
 * ----------------------------------------------------------------------------------------
 */
define('THEMEROOT', get_stylesheet_directory_uri());
define('IMAGES', THEMEROOT . '/images');
define('SCRIPTS', THEMEROOT . '/js');
require_once('class-wp-bootstrap-navwalker.php');
require_once('latest_widget.php');
//add_filter('acf/settings/show_admin', '__return_false');


/**
 * ----------------------------------------------------------------------------------------
 * 4.0 - Set up theme default and register various supported features.
 * ----------------------------------------------------------------------------------------
 */

if (!function_exists('alpha_setup')) {
    function alpha_setup()
    {
        /**
         * Make the theme available for translation.
         */
        $lang_dir = THEMEROOT . '/languages';
        load_theme_textdomain('alpha', $lang_dir);

        /**
         * Add support for post formats.
         */
//		add_theme_support( 'post-formats',
//			array(
//				'gallery',
//				'link',
//				'image',
//				'quote',
//				'video',
//				'audio'
//			)
//		);

        /**
         * Add support for automatic feed links.
         */
        add_theme_support('automatic-feed-links');
        add_theme_support('widgets');

        /**
         * Add support for post thumbnails.
         */
        add_theme_support('post-thumbnails');
        add_theme_support('yoast-seo-breadcrumbs');


        /**
         * Register nav menus.
         */
        register_nav_menus(
            array(
                'main' => __('القائمة الرئيسية', 'alpha'),
                'footer' => __('قائمة الفوتر', 'alpha')
            )
        );
    }

    add_action('after_setup_theme', 'alpha_setup');
}


/**
 * ----------------------------------------------------------------------------------------
 * 10.0 - Load the custom scripts for the theme.
 * ----------------------------------------------------------------------------------------
 */
if (!function_exists('alpha_scripts')) {
    function alpha_scripts()
    {
        // Adds support for pages with threaded comments
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        // Register scripts
        wp_register_script('bootstrap-js', SCRIPTS . '/bootstrap.min.js', array('jquery'), false, true);
//        wp_register_script('bootstrap-js-rtl', SCRIPTS . '/bootstrap-rtl.js', array('jquery'), false, true);
//        wp_register_script('carousel', SCRIPTS . '/owl.carousel.min.js', array('jquery'), false, true);
        wp_register_script('lazyload', SCRIPTS . '/lazyload.min.js', array('jquery'), false, true);
        wp_register_script('wow', SCRIPTS . '/wow.min.js', array('jquery'), false, true);
        wp_register_script('popper', SCRIPTS . '/popper.min.js', array('jquery'), false, true);
        wp_register_script('magnific', SCRIPTS . '/jquery.magnific-popup.min.js', array('jquery'), false, true);


        // Load the custom scripts
        wp_enqueue_script('bootstrap-js');
//        wp_enqueue_script('bootstrap-js-rtl');
//        wp_enqueue_script('carousel');
        wp_enqueue_script('lazyload');
        wp_enqueue_script('wow');
        wp_enqueue_script('popper');
        wp_enqueue_script('magnific');


        wp_register_script('custom', SCRIPTS . '/custom.js', array('jquery'), false, true);
        wp_enqueue_script('custom');


        // Load the stylesheets
        wp_enqueue_style('bootstrap', THEMEROOT . '/css/bootstrap.min.css');
        wp_enqueue_style('Fontawesome', THEMEROOT . '/css/font-awesome.min.css');
        wp_enqueue_style('animate', THEMEROOT . '/css/animate.css');
//        wp_enqueue_style('OWL', THEMEROOT . '/css/owl.carousel.min.css');
        wp_enqueue_style('magnific', THEMEROOT . '/css/magnific-popup.css');

        if (is_rtl()) {

//            wp_enqueue_style('bootstrap-rtl', THEMEROOT . '/css/bootstrap-rtl.css');

            wp_enqueue_style('rtl', THEMEROOT . '/style.css');

        } else {
            wp_enqueue_style('en', THEMEROOT . '/en.css');
        }

    }

    add_action('wp_enqueue_scripts', 'alpha_scripts');
}


/**
 * ----------------------------------------------------------------------------------------
 * 11.0 - Custom Post Type.
 * ----------------------------------------------------------------------------------------
 */
//
//
//register_post_type('slider', array(
//
//    'public' => true,
//
//    'hierarchical' => false,
//
//    'exclude_from_search' => false,
//
//    'has_archive' => true,
//
//    'rewrite' => array('slug' => 'slider'),
//
//    'capability_type' => 'post',
//
//    'menu_icon' => 'dashicons-images-alt2',
//
//    'taxonomies' => array('post_tag'),
//
//    'labels' => array(
//
//        'name' => 'السلايدر',
//
//        'menu_name' => 'السلايدر',
//
//        'name_admin_bar' => 'سلايدر'
//
//
//    ),
//
//    'supports' => array('title', 'thumbnail', 'editor')
//
//));
//
//register_post_type('services', array(
//
//    'public' => true,
//    'hierarchical' => false,
//    'exclude_from_search' => false,
//    'has_archive' => true,
//    'rewrite' => array('slug' => 'services'),
//    'capability_type' => 'post',
//    'menu_icon' => 'dashicons-megaphone',
//    'taxonomies' => array('post_tag'),
//    'labels' => array(
//        'name' => 'الخدمات',
//        'menu_name' => 'الخدمات',
//        'name_admin_bar' => 'خدمة'
//    ),
//    'supports' => array('title', 'thumbnail', 'editor')
//));
//
//register_post_type('media', array(
//
//    'public' => true,
//
//    'hierarchical' => false,
//
//    'exclude_from_search' => false,
//
//    'has_archive' => true,
//
//    'rewrite' => array('slug' => 'media'),
//
//    'capability_type' => 'post',
//
//    'menu_icon' => 'dashicons-format-video',
//
//    'taxonomies' => array('post_tag'),
//
//    'labels' => array(
//
//        'name' => 'الصور والفيديو',
//
//        'menu_name' => 'الصور والفيديو',
//
//        'name_admin_bar' => 'ملف ميديا'
//
//
//    ),
//
//    'supports' => array('title', 'tags', 'thumbnail', 'editor')
//
//));


/*************************************************/
/* Register Taxonami */
/*************************************************/
//add_action('init', 'create_sections');
//
//function create_sections()
//{
//    register_taxonomy(
//        'sections',
//        'radio',
//        array(
//            'label' => __('تصنيفات البرامج'),
//            'hierarchical' => true,
//            'show_ui' => true,
//            'show_admin_column' => true,
//            'show_in_nav_menus' => true,
//            'show_tagcloud' => true,
//            'public' => true
//        )
//
//    );
//
//}


/*************************************************/
/* Page Option */
/*************************************************/


if (function_exists('acf_add_options_page')) {

    acf_add_options_page(array(
        'page_title' => 'Theme Settings',
        'menu_title' => 'Theme Settings',
        'menu_slug' => 'theme-general-settings',
        'capability' => 'edit_posts',
        'update_button' => 'Save and publish',
        'redirect' => false
    ));

}

function mytheme_admin_bar_render()
{
    global $wp_admin_bar;
    $wp_admin_bar->add_menu(array(
        'id' => 'themeoptions',
        'title' => __('Theme Settings', 'some-textdomain'),
        'href' => admin_url('admin.php?page=theme-general-settings')
    ));
}

// and we hook our function via
add_action('wp_before_admin_bar_render', 'mytheme_admin_bar_render');


/*************************************************/
/* Sidebar */
/*************************************************/
if (function_exists('register_sidebar')) {
    register_sidebar(
        array(
            'name' => 'sidebar',
            'id' => 'sidebar',
            'description' => 'Sidebar',
            'before_widget' => '<div class="rest-of-news">',
            'after_widget' => '</div>',
            'before_title' => '<h6 class="box-section-title">',
            'after_title' => '</h6>'

        )
    );
}
if (!isset($content_width)) {
    $content_width = 1170;
}

function youtubeThumbnailUrl($vidurl)
{
    $urlArr = explode("=", $vidurl);
    $urlArrNum = count($urlArr);
    $youtubeVideoId = $urlArr[$urlArrNum - 1];
    return 'http://img.youtube.com/vi/' . $youtubeVideoId . '/mqdefault.jpg';
};


//Insert ads after second paragraph of single post content.
add_filter( 'the_content', 'prefix_insert_post_ads' );
function prefix_insert_post_ads( $content ) {
    $ad_code = get_field('middle_post_ad','options');
    if ( is_single() && ! is_admin() ) {
        return prefix_insert_after_paragraph( $ad_code, 2, $content );
    }
    return $content;
}
// Parent Function that makes the magic happen
function prefix_insert_after_paragraph( $insertion, $paragraph_id, $content ) {
    $closing_p = '</p>';
    $paragraphs = explode( $closing_p, $content );
    foreach ($paragraphs as $index => $paragraph) {
        if ( trim( $paragraph ) ) {
            $paragraphs[$index] .= $closing_p;
        }
        if ( $paragraph_id == $index + 1 ) {
            $paragraphs[$index] .= $insertion;
        }
    }
    return implode( '', $paragraphs );
};